#!/bin/sh
BASE_DIR=$(realpath $(dirname $0))
cd $BASE_DIR
ROOT=$PWD
if [ "$1" = "--summary" ]; then
  OUTPUT=$BASE_DIR/output.log
  cat /dev/null > $OUTPUT
else
  OUTPUT=/dev/stdout
fi
export KSFT_TAP_LEVEL=1
echo ; echo TAP version 13
echo Running tests in android
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in android" >> /dev/kmsg
cd android
./run.sh
cd $ROOT
echo ; echo TAP version 13
echo Running tests in bpf
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in bpf" >> /dev/kmsg
cd bpf
(./test_verifier >> $OUTPUT 2>&1 && echo "selftests: test_verifier [PASS]") || echo "selftests: test_verifier [FAIL]"
(./test_tag >> $OUTPUT 2>&1 && echo "selftests: test_tag [PASS]") || echo "selftests: test_tag [FAIL]"
(./test_maps >> $OUTPUT 2>&1 && echo "selftests: test_maps [PASS]") || echo "selftests: test_maps [FAIL]"
(./test_lru_map >> $OUTPUT 2>&1 && echo "selftests: test_lru_map [PASS]") || echo "selftests: test_lru_map [FAIL]"
(./test_lpm_map >> $OUTPUT 2>&1 && echo "selftests: test_lpm_map [PASS]") || echo "selftests: test_lpm_map [FAIL]"
(./test_progs >> $OUTPUT 2>&1 && echo "selftests: test_progs [PASS]") || echo "selftests: test_progs [FAIL]"
(./test_align >> $OUTPUT 2>&1 && echo "selftests: test_align [PASS]") || echo "selftests: test_align [FAIL]"
(./test_verifier_log >> $OUTPUT 2>&1 && echo "selftests: test_verifier_log [PASS]") || echo "selftests: test_verifier_log [FAIL]"
(./test_dev_cgroup >> $OUTPUT 2>&1 && echo "selftests: test_dev_cgroup [PASS]") || echo "selftests: test_dev_cgroup [FAIL]"
(./test_tcpbpf_user >> $OUTPUT 2>&1 && echo "selftests: test_tcpbpf_user [PASS]") || echo "selftests: test_tcpbpf_user [FAIL]"
(./test_sock >> $OUTPUT 2>&1 && echo "selftests: test_sock [PASS]") || echo "selftests: test_sock [FAIL]"
(./test_btf >> $OUTPUT 2>&1 && echo "selftests: test_btf [PASS]") || echo "selftests: test_btf [FAIL]"
(./test_sockmap >> $OUTPUT 2>&1 && echo "selftests: test_sockmap [PASS]") || echo "selftests: test_sockmap [FAIL]"
(./urandom_read >> $OUTPUT 2>&1 && echo "selftests: urandom_read [PASS]") || echo "selftests: urandom_read [FAIL]"
(./test_kmod.sh >> $OUTPUT 2>&1 && echo "selftests: test_kmod.sh [PASS]") || echo "selftests: test_kmod.sh [FAIL]"
(./test_libbpf.sh >> $OUTPUT 2>&1 && echo "selftests: test_libbpf.sh [PASS]") || echo "selftests: test_libbpf.sh [FAIL]"
(./test_xdp_redirect.sh >> $OUTPUT 2>&1 && echo "selftests: test_xdp_redirect.sh [PASS]") || echo "selftests: test_xdp_redirect.sh [FAIL]"
(./test_xdp_meta.sh >> $OUTPUT 2>&1 && echo "selftests: test_xdp_meta.sh [PASS]") || echo "selftests: test_xdp_meta.sh [FAIL]"
(./test_offload.py >> $OUTPUT 2>&1 && echo "selftests: test_offload.py [PASS]") || echo "selftests: test_offload.py [FAIL]"
(./test_sock_addr.sh >> $OUTPUT 2>&1 && echo "selftests: test_sock_addr.sh [PASS]") || echo "selftests: test_sock_addr.sh [FAIL]"
(./test_tunnel.sh >> $OUTPUT 2>&1 && echo "selftests: test_tunnel.sh [PASS]") || echo "selftests: test_tunnel.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in breakpoints
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in breakpoints" >> /dev/kmsg
cd breakpoints
(./step_after_suspend_test >> $OUTPUT 2>&1 && echo "selftests: step_after_suspend_test [PASS]") || echo "selftests: step_after_suspend_test [FAIL]"
(./breakpoint_test_arm64 >> $OUTPUT 2>&1 && echo "selftests: breakpoint_test_arm64 [PASS]") || echo "selftests: breakpoint_test_arm64 [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in capabilities
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in capabilities" >> /dev/kmsg
cd capabilities
(./test_execve >> $OUTPUT 2>&1 && echo "selftests: test_execve [PASS]") || echo "selftests: test_execve [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in cpufreq
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in cpufreq" >> /dev/kmsg
cd cpufreq
(./main.sh >> $OUTPUT 2>&1 && echo "selftests: main.sh [PASS]") || echo "selftests: main.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in cpu-hotplug
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in cpu-hotplug" >> /dev/kmsg
cd cpu-hotplug
(./cpu-on-off-test.sh >> $OUTPUT 2>&1 && echo "selftests: cpu-on-off-test.sh [PASS]") || echo "selftests: cpu-on-off-test.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in efivarfs
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in efivarfs" >> /dev/kmsg
cd efivarfs
(./efivarfs.sh >> $OUTPUT 2>&1 && echo "selftests: efivarfs.sh [PASS]") || echo "selftests: efivarfs.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in exec
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in exec" >> /dev/kmsg
cd exec
(./execveat >> $OUTPUT 2>&1 && echo "selftests: execveat [PASS]") || echo "selftests: execveat [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in filesystems
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in filesystems" >> /dev/kmsg
cd filesystems
(./devpts_pts >> $OUTPUT 2>&1 && echo "selftests: devpts_pts [PASS]") || echo "selftests: devpts_pts [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in firmware
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in firmware" >> /dev/kmsg
cd firmware
(./fw_run_tests.sh >> $OUTPUT 2>&1 && echo "selftests: fw_run_tests.sh [PASS]") || echo "selftests: fw_run_tests.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in ftrace
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in ftrace" >> /dev/kmsg
cd ftrace
(./ftracetest >> $OUTPUT 2>&1 && echo "selftests: ftracetest [PASS]") || echo "selftests: ftracetest [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in futex
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in futex" >> /dev/kmsg
cd futex
./run.sh
cd $ROOT
echo ; echo TAP version 13
echo Running tests in gpio
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in gpio" >> /dev/kmsg
cd gpio
(./gpio-mockup.sh >> $OUTPUT 2>&1 && echo "selftests: gpio-mockup.sh [PASS]") || echo "selftests: gpio-mockup.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in intel_pstate
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in intel_pstate" >> /dev/kmsg
cd intel_pstate
(./run.sh >> $OUTPUT 2>&1 && echo "selftests: run.sh [PASS]") || echo "selftests: run.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in ipc
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in ipc" >> /dev/kmsg
cd ipc
(./msgque >> $OUTPUT 2>&1 && echo "selftests: msgque [PASS]") || echo "selftests: msgque [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in kcmp
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in kcmp" >> /dev/kmsg
cd kcmp
(./kcmp_test >> $OUTPUT 2>&1 && echo "selftests: kcmp_test [PASS]") || echo "selftests: kcmp_test [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in kvm
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in kvm" >> /dev/kmsg
cd kvm
(./set_sregs_test >> $OUTPUT 2>&1 && echo "selftests: set_sregs_test [PASS]") || echo "selftests: set_sregs_test [FAIL]"
(./sync_regs_test >> $OUTPUT 2>&1 && echo "selftests: sync_regs_test [PASS]") || echo "selftests: sync_regs_test [FAIL]"
(./vmx_tsc_adjust_test >> $OUTPUT 2>&1 && echo "selftests: vmx_tsc_adjust_test [PASS]") || echo "selftests: vmx_tsc_adjust_test [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in lib
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in lib" >> /dev/kmsg
cd lib
(./printf.sh >> $OUTPUT 2>&1 && echo "selftests: printf.sh [PASS]") || echo "selftests: printf.sh [FAIL]"
(./bitmap.sh >> $OUTPUT 2>&1 && echo "selftests: bitmap.sh [PASS]") || echo "selftests: bitmap.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in membarrier
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in membarrier" >> /dev/kmsg
cd membarrier
(./membarrier_test >> $OUTPUT 2>&1 && echo "selftests: membarrier_test [PASS]") || echo "selftests: membarrier_test [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in memfd
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in memfd" >> /dev/kmsg
cd memfd
(./run_tests.sh >> $OUTPUT 2>&1 && echo "selftests: run_tests.sh [PASS]") || echo "selftests: run_tests.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in memory-hotplug
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in memory-hotplug" >> /dev/kmsg
cd memory-hotplug
./mem-on-off-test.sh -r 2 && echo selftests: memory-hotplug [PASS] || echo selftests: memory-hotplug [FAIL]
cd $ROOT
echo ; echo TAP version 13
echo Running tests in mount
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in mount" >> /dev/kmsg
cd mount
if [ -f /proc/self/uid_map ] ; then ./unprivileged-remount-test ; else echo WARN: No /proc/self/uid_map exist, test skipped. ; fi
cd $ROOT
echo ; echo TAP version 13
echo Running tests in mqueue
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in mqueue" >> /dev/kmsg
cd mqueue
./mq_open_tests /test1 || echo "selftests: mq_open_tests [FAIL]"
./mq_perf_tests || echo "selftests: mq_perf_tests [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in net
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in net" >> /dev/kmsg
cd net
(./reuseport_bpf >> $OUTPUT 2>&1 && echo "selftests: reuseport_bpf [PASS]") || echo "selftests: reuseport_bpf [FAIL]"
(./reuseport_bpf_cpu >> $OUTPUT 2>&1 && echo "selftests: reuseport_bpf_cpu [PASS]") || echo "selftests: reuseport_bpf_cpu [FAIL]"
(./reuseport_bpf_numa >> $OUTPUT 2>&1 && echo "selftests: reuseport_bpf_numa [PASS]") || echo "selftests: reuseport_bpf_numa [FAIL]"
(./reuseport_dualstack >> $OUTPUT 2>&1 && echo "selftests: reuseport_dualstack [PASS]") || echo "selftests: reuseport_dualstack [FAIL]"
(./reuseaddr_conflict >> $OUTPUT 2>&1 && echo "selftests: reuseaddr_conflict [PASS]") || echo "selftests: reuseaddr_conflict [FAIL]"
(./run_netsocktests >> $OUTPUT 2>&1 && echo "selftests: run_netsocktests [PASS]") || echo "selftests: run_netsocktests [FAIL]"
(./run_afpackettests >> $OUTPUT 2>&1 && echo "selftests: run_afpackettests [PASS]") || echo "selftests: run_afpackettests [FAIL]"
(./test_bpf.sh >> $OUTPUT 2>&1 && echo "selftests: test_bpf.sh [PASS]") || echo "selftests: test_bpf.sh [FAIL]"
(./netdevice.sh >> $OUTPUT 2>&1 && echo "selftests: netdevice.sh [PASS]") || echo "selftests: netdevice.sh [FAIL]"
(./rtnetlink.sh >> $OUTPUT 2>&1 && echo "selftests: rtnetlink.sh [PASS]") || echo "selftests: rtnetlink.sh [FAIL]"
(./fib_tests.sh >> $OUTPUT 2>&1 && echo "selftests: fib_tests.sh [PASS]") || echo "selftests: fib_tests.sh [FAIL]"
(./fib-onlink-tests.sh >> $OUTPUT 2>&1 && echo "selftests: fib-onlink-tests.sh [PASS]") || echo "selftests: fib-onlink-tests.sh [FAIL]"
(./in_netns.sh >> $OUTPUT 2>&1 && echo "selftests: in_netns.sh [PASS]") || echo "selftests: in_netns.sh [FAIL]"
(./pmtu.sh >> $OUTPUT 2>&1 && echo "selftests: pmtu.sh [PASS]") || echo "selftests: pmtu.sh [FAIL]"
(./udpgso.sh >> $OUTPUT 2>&1 && echo "selftests: udpgso.sh [PASS]") || echo "selftests: udpgso.sh [FAIL]"
(./udpgso_bench.sh >> $OUTPUT 2>&1 && echo "selftests: udpgso_bench.sh [PASS]") || echo "selftests: udpgso_bench.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in nsfs
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in nsfs" >> /dev/kmsg
cd nsfs
(./owner >> $OUTPUT 2>&1 && echo "selftests: owner [PASS]") || echo "selftests: owner [FAIL]"
(./pidns >> $OUTPUT 2>&1 && echo "selftests: pidns [PASS]") || echo "selftests: pidns [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in powerpc
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in powerpc" >> /dev/kmsg
cd powerpc
cd $ROOT
echo ; echo TAP version 13
echo Running tests in proc
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in proc" >> /dev/kmsg
cd proc
(./proc-loadavg-001 >> $OUTPUT 2>&1 && echo "selftests: proc-loadavg-001 [PASS]") || echo "selftests: proc-loadavg-001 [FAIL]"
(./proc-self-map-files-001 >> $OUTPUT 2>&1 && echo "selftests: proc-self-map-files-001 [PASS]") || echo "selftests: proc-self-map-files-001 [FAIL]"
(./proc-self-map-files-002 >> $OUTPUT 2>&1 && echo "selftests: proc-self-map-files-002 [PASS]") || echo "selftests: proc-self-map-files-002 [FAIL]"
(./proc-self-syscall >> $OUTPUT 2>&1 && echo "selftests: proc-self-syscall [PASS]") || echo "selftests: proc-self-syscall [FAIL]"
(./proc-self-wchan >> $OUTPUT 2>&1 && echo "selftests: proc-self-wchan [PASS]") || echo "selftests: proc-self-wchan [FAIL]"
(./proc-uptime-001 >> $OUTPUT 2>&1 && echo "selftests: proc-uptime-001 [PASS]") || echo "selftests: proc-uptime-001 [FAIL]"
(./proc-uptime-002 >> $OUTPUT 2>&1 && echo "selftests: proc-uptime-002 [PASS]") || echo "selftests: proc-uptime-002 [FAIL]"
(./read >> $OUTPUT 2>&1 && echo "selftests: read [PASS]") || echo "selftests: read [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in pstore
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in pstore" >> /dev/kmsg
cd pstore
(./pstore_tests >> $OUTPUT 2>&1 && echo "selftests: pstore_tests [PASS]") || echo "selftests: pstore_tests [FAIL]"
(./pstore_post_reboot_tests >> $OUTPUT 2>&1 && echo "selftests: pstore_post_reboot_tests [PASS]") || echo "selftests: pstore_post_reboot_tests [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in ptrace
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in ptrace" >> /dev/kmsg
cd ptrace
(./peeksiginfo >> $OUTPUT 2>&1 && echo "selftests: peeksiginfo [PASS]") || echo "selftests: peeksiginfo [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in seccomp
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in seccomp" >> /dev/kmsg
cd seccomp
(./seccomp_bpf >> $OUTPUT 2>&1 && echo "selftests: seccomp_bpf [PASS]") || echo "selftests: seccomp_bpf [FAIL]"
(./seccomp_benchmark >> $OUTPUT 2>&1 && echo "selftests: seccomp_benchmark [PASS]") || echo "selftests: seccomp_benchmark [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in sigaltstack
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in sigaltstack" >> /dev/kmsg
cd sigaltstack
(./sas >> $OUTPUT 2>&1 && echo "selftests: sas [PASS]") || echo "selftests: sas [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in size
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in size" >> /dev/kmsg
cd size
(./get_size >> $OUTPUT 2>&1 && echo "selftests: get_size [PASS]") || echo "selftests: get_size [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in splice
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in splice" >> /dev/kmsg
cd splice
(./default_file_splice_read.sh >> $OUTPUT 2>&1 && echo "selftests: default_file_splice_read.sh [PASS]") || echo "selftests: default_file_splice_read.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in static_keys
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in static_keys" >> /dev/kmsg
cd static_keys
(./test_static_keys.sh >> $OUTPUT 2>&1 && echo "selftests: test_static_keys.sh [PASS]") || echo "selftests: test_static_keys.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in sync
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in sync" >> /dev/kmsg
cd sync
(./sync_test >> $OUTPUT 2>&1 && echo "selftests: sync_test [PASS]") || echo "selftests: sync_test [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in sysctl
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in sysctl" >> /dev/kmsg
cd sysctl
(./sysctl.sh >> $OUTPUT 2>&1 && echo "selftests: sysctl.sh [PASS]") || echo "selftests: sysctl.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in timers
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in timers" >> /dev/kmsg
cd timers
(./posix_timers >> $OUTPUT 2>&1 && echo "selftests: posix_timers [PASS]") || echo "selftests: posix_timers [FAIL]"
(./nanosleep >> $OUTPUT 2>&1 && echo "selftests: nanosleep [PASS]") || echo "selftests: nanosleep [FAIL]"
(./nsleep-lat >> $OUTPUT 2>&1 && echo "selftests: nsleep-lat [PASS]") || echo "selftests: nsleep-lat [FAIL]"
(./set-timer-lat >> $OUTPUT 2>&1 && echo "selftests: set-timer-lat [PASS]") || echo "selftests: set-timer-lat [FAIL]"
(./mqueue-lat >> $OUTPUT 2>&1 && echo "selftests: mqueue-lat [PASS]") || echo "selftests: mqueue-lat [FAIL]"
(./inconsistency-check >> $OUTPUT 2>&1 && echo "selftests: inconsistency-check [PASS]") || echo "selftests: inconsistency-check [FAIL]"
(./raw_skew >> $OUTPUT 2>&1 && echo "selftests: raw_skew [PASS]") || echo "selftests: raw_skew [FAIL]"
(./threadtest >> $OUTPUT 2>&1 && echo "selftests: threadtest [PASS]") || echo "selftests: threadtest [FAIL]"
(./rtctest >> $OUTPUT 2>&1 && echo "selftests: rtctest [PASS]") || echo "selftests: rtctest [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in user
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in user" >> /dev/kmsg
cd user
(./test_user_copy.sh >> $OUTPUT 2>&1 && echo "selftests: test_user_copy.sh [PASS]") || echo "selftests: test_user_copy.sh [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in vm
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in vm" >> /dev/kmsg
cd vm
(./run_vmtests >> $OUTPUT 2>&1 && echo "selftests: run_vmtests [PASS]") || echo "selftests: run_vmtests [FAIL]"
cd $ROOT
echo ; echo TAP version 13
echo Running tests in x86
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in x86" >> /dev/kmsg
cd x86
cd $ROOT
echo ; echo TAP version 13
echo Running tests in zram
echo ========================================
[ -w /dev/kmsg ] && echo "kselftest: Running tests in zram" >> /dev/kmsg
cd zram
(./zram.sh >> $OUTPUT 2>&1 && echo "selftests: zram.sh [PASS]") || echo "selftests: zram.sh [FAIL]"
cd $ROOT
